rainmaker

Module param

A module for Parameters. One or more parameters can be assigned with multiple devices.

A single instance of parameter can be assigned to multiple devices.

Initialization for standard parameters(Power, Brightness, Hue, Saturation) can be done using specified standard methods.

Structs

Enums