A module for Parameters. One or more parameters can be assigned with multiple devices.
A single instance of parameter can be assigned to multiple devices.
Initialization for standard parameters(Power, Brightness, Hue, Saturation) can be done using specified standard methods.
Structs
Enums
- Set of access mode parameter.
- Set of the parameter type.
- Set of standard UI elements.
- Set of the type of parameter value.